@@ -1,19 +1,32 @@
 use crate::core::prelude::*;
-use crate::widgets::sync_fifo::SynchronousFIFO;
+use crate::widgets::async_fifo::AsynchronousFIFO;
 use crate::widgets::dff::DFF;
-use crate::widgets::prelude::TristateBuffer;
+use crate::widgets::prelude::{SynchronousFIFO, TristateBuffer};
 
 #[derive(Clone, Debug, Default, LogicInterface)]
+#[join = "FifoBusIn"]
 pub struct FifoBus<T: Synth> {
-    pub to_bus: Signal<Out, T>,
+    pub to_bus: Signal<In, T>,
     pub write: Signal<In, Bit>,
     pub full: Signal<Out, Bit>,
-    pub from_bus: Signal<In, T>,
+    pub from_bus: Signal<Out, T>,
     pub read: Signal<In, Bit>,
     pub empty: Signal<Out, Bit>,
 }
 
 #[derive(Clone, Debug, Default, LogicInterface)]
+#[join = "FifoBus"]
+pub struct FifoBusIn<T: Synth> {
+    pub to_bus: Signal<Out, T>,
+    pub write: Signal<Out, Bit>,
+    pub full: Signal<In, Bit>,
+    pub from_bus: Signal<In, T>,
+    pub read: Signal<Out, Bit>,
+    pub empty: Signal<In, Bit>,
+}
+
+#[derive(Clone, Debug, Default, LogicInterface)]
+#[join = "BidiBusD"]
 pub struct BidiBusM<T: Synth> {
     pub sig_inout: Signal<InOut, T>,
     pub sig_empty: Signal<In, Bit>,
@@ -24,6 +37,7 @@ pub struct BidiBusM<T: Synth> {
 }
 
 #[derive(Clone, Debug, Default, LogicInterface)]
+#[join = "BidiBusM"]
 pub struct BidiBusD<T: Synth> {
     pub sig_inout: Signal<InOut, T>,
     pub sig_empty: Signal<Out, Bit>,
@@ -33,15 +47,15 @@ pub struct BidiBusD<T: Synth> {
     pub sig_master: Signal<In, Bit>,
 }
 
-
 #[derive(LogicBlock, Default)]
 pub struct BidiMaster<T: Synth, const N: usize, const NP1: usize> {
     pub bus: BidiBusM<T>,
-    pub clock: Signal<In, Clock>,
+    pub bus_clock: Signal<In, Clock>,
     bus_buffer: TristateBuffer<T>,
-    fifo_to_bus: SynchronousFIFO<T, N, NP1, 1>,
-    fifo_from_bus: SynchronousFIFO<T, N, NP1, 1>,
+    fifo_to_bus: AsynchronousFIFO<T, N, NP1, 1>,
+    fifo_from_bus: AsynchronousFIFO<T, N, NP1, 1>,
     pub data: FifoBus<T>,
+    pub data_clock: Signal<In, Clock>,
     state: DFF<BidiState>,
     can_send_to_bus: Signal<Local, Bit>,
     can_read_from_bus: Signal<Local, Bit>,
@@ -51,9 +65,11 @@ impl<T: Synth, const N: usize, const NP1: usize> Logic for BidiMaster<T, N, NP1>
     #[hdl_gen]
     fn update(&mut self) {
         // Clock the logic
-        self.fifo_to_bus.clock.next = self.clock.val();
-        self.fifo_from_bus.clock.next = self.clock.val();
-        self.state.clk.next = self.clock.val();
+        self.fifo_to_bus.read_clock.next = self.bus_clock.val();
+        self.fifo_from_bus.write_clock.next = self.bus_clock.val();
+        self.fifo_to_bus.write_clock.next = self.data_clock.val();
+        self.fifo_from_bus.read_clock.next = self.data_clock.val();
+        self.state.clk.next = self.bus_clock.val();
         // Latch prevention
         self.state.d.next = self.state.q.val();
         self.bus_buffer.write_enable.next = false;
@@ -118,7 +134,6 @@ impl<T: Synth, const N: usize, const NP1: usize> Logic for BidiMaster<T, N, NP1>
     }
 }
 
-
 #[derive(LogicState, Debug, Copy, Clone, PartialEq)]
 enum BidiState {
     Idle,
@@ -133,7 +148,7 @@ enum BidiState {
 fn test_bidi_master2_synthesizable() {
     let mut uut = BidiMaster::<Bits<8>, 8, 9>::default();
     uut.bus.link_connect_dest();
-    uut.clock.connect();
+    uut.bus_clock.connect();
     uut.data.write.connect();
     uut.data.read.connect();
     uut.data.to_bus.connect();
@@ -144,7 +159,7 @@ fn test_bidi_master2_synthesizable() {
 }
 
 #[derive(LogicBlock, Default)]
-pub struct BidiDevice<T: Synth, const N: usize, const NP1: usize> {
+pub struct BidiSimulatedDevice<T: Synth, const N: usize, const NP1: usize> {
     pub bus: BidiBusD<T>,
     pub clock: Signal<In, Clock>,
     bus_buffer: TristateBuffer<T>,
@@ -153,7 +168,7 @@ pub struct BidiDevice<T: Synth, const N: usize, const NP1: usize> {
     pub data: FifoBus<T>,
 }
 
-impl<T: Synth, const N: usize, const NP1: usize> Logic for BidiDevice<T, N, NP1> {
+impl<T: Synth, const N: usize, const NP1: usize> Logic for BidiSimulatedDevice<T, N, NP1> {
     #[hdl_gen]
     fn update(&mut self) {
         // Clock the logic
@@ -186,7 +201,7 @@ impl<T: Synth, const N: usize, const NP1: usize> Logic for BidiDevice<T, N, NP1>
 
 #[test]
 fn test_bidi_device_synthesizable() {
-    let mut uut = BidiDevice::<Bits<8>, 8, 9>::default();
+    let mut uut = BidiSimulatedDevice::<Bits<8>, 8, 9>::default();
     uut.bus.connect();
     uut.data.read.connect();
     uut.data.write.connect();
