@@ -65,8 +65,8 @@ pub struct I2CDriver {
 impl Logic for I2CDriver {
     #[hdl_gen]
     fn update(&mut self) {
-        Signal::<InOut,Bit>::link(&mut self.sda,&mut self.sda_driver.bus);
-        Signal::<InOut,Bit>::link(&mut self.scl,&mut self.scl_driver.bus);
+        Signal::<InOut, Bit>::link(&mut self.sda, &mut self.sda_driver.bus);
+        Signal::<InOut, Bit>::link(&mut self.scl, &mut self.scl_driver.bus);
         // Clock the internal structures
         self.state.clk.next = self.clock.val();
         self.delay.clock.next = self.clock.val();
@@ -300,134 +300,3 @@ fn test_i2c_driver_synthesizes() {
     let vlog = generate_verilog(&uut);
     yosys_validate("i2cdriver", &vlog).unwrap()
 }
-
-#[derive(LogicBlock)]
-struct I2CDriverTest {
-    clock: Signal<In, Clock>,
-    driver: I2CDriver,
-    target: I2CTarget,
-    pullup_sda: TristateBuffer<Bit>,
-    pullup_scl: TristateBuffer<Bit>,
-}
-
-impl Logic for I2CDriverTest {
-    #[hdl_gen]
-    fn update(&mut self) {
-        self.driver.clock.next = self.clock.val();
-        self.target.clock.next = self.clock.val();
-        Signal::<InOut, Bit>::join(&mut self.pullup_scl.bus, &mut self.driver.scl);
-        Signal::<InOut, Bit>::join(&mut self.pullup_sda.bus, &mut self.driver.sda);
-        Signal::<InOut, Bit>::join(&mut self.pullup_scl.bus, &mut self.target.scl);
-        Signal::<InOut, Bit>::join(&mut self.pullup_sda.bus, &mut self.target.sda);
-        Signal::<InOut, Bit>::join(&mut self.driver.sda, &mut self.target.sda);
-        Signal::<InOut, Bit>::join(&mut self.driver.scl, &mut self.target.scl);
-        self.pullup_scl.write_data.next = true;
-        self.pullup_sda.write_data.next = true;
-        self.driver.reset.next = false;
-        self.target.active.next = false;
-    }
-}
-
-impl Default for I2CDriverTest {
-    fn default() -> Self {
-        let config = I2CConfig {
-            delay_time: Duration::from_micros(10),
-            clock_speed_hz: 1_000_000,
-        };
-        Self {
-            clock: Default::default(),
-            driver: I2CDriver::new(config),
-            target: I2CTarget::default(),
-            pullup_sda: Default::default(),
-            pullup_scl: Default::default(),
-        }
-    }
-}
-
-#[test]
-fn test_i2c_driver_operation() {
-    let mut uut = I2CDriverTest::default();
-    uut.clock.connect();
-    uut.driver.cmd.connect();
-    uut.driver.run.connect();
-    uut.pullup_scl.write_enable.connect();
-    uut.pullup_sda.write_enable.connect();
-    uut.connect_all();
-    //uut.sim_sda.bus.
-    let mut sim = Simulation::new();
-    sim.add_clock(500_000, |x: &mut Box<I2CDriverTest>| {
-        x.clock.next = !x.clock.val()
-    });
-    sim.add_custom_logic(|x| {
-        x.pullup_sda.write_enable.next =
-            !x.driver.sda.is_driving_tristate() & !x.target.sda.is_driving_tristate();
-        x.pullup_scl.write_enable.next =
-            !x.driver.scl.is_driving_tristate() & !x.target.scl.is_driving_tristate();
-    });
-    let bits = [true, false, false, true, true, false, true, true];
-    sim.add_testbench(move |mut sim: Sim<I2CDriverTest>| {
-        let mut x = sim.init()?;
-        wait_clock_true!(sim, clock, x);
-        x = sim.watch(|x| x.target.bus_write.val(), x)?;
-        sim_assert!(sim, x.target.from_bus.val() == 0b10011011_u8, x);
-        wait_clock_cycle!(sim, clock, x);
-        x = sim.watch(|x| x.target.bus_write.val(), x)?;
-        sim_assert!(sim, x.target.from_bus.val() == 0b10011011_u8, x);
-        sim.done(x)
-    });
-    sim.add_testbench(move |mut sim: Sim<I2CDriverTest>| {
-        let mut x = sim.init()?;
-        wait_clock_true!(sim, clock, x);
-        x.driver.cmd.next = I2CDriverCmd::SendStart;
-        x.driver.run.next = true;
-        wait_clock_cycle!(sim, clock, x);
-        x.driver.run.next = false;
-        x = sim.watch(|x| !x.driver.busy.val(), x)?;
-        for bit in &bits {
-            wait_clock_true!(sim, clock, x);
-            x.driver.cmd.next = if *bit {
-                I2CDriverCmd::SendTrue
-            } else {
-                I2CDriverCmd::SendFalse
-            };
-            x.driver.run.next = true;
-            wait_clock_cycle!(sim, clock, x);
-            x.driver.run.next = false;
-            x = sim.watch(|x| !x.driver.busy.val(), x)?;
-        }
-        x.driver.cmd.next = I2CDriverCmd::GetBit;
-        x.driver.run.next = true;
-        wait_clock_cycle!(sim, clock, x);
-        x = sim.watch(|x| !x.driver.busy.val(), x)?;
-        x.driver.cmd.next = I2CDriverCmd::Restart;
-        x.driver.run.next = true;
-        wait_clock_cycle!(sim, clock, x);
-        x.driver.run.next = false;
-        x = sim.watch(|x| !x.driver.busy.val(), x)?;
-        for bit in &bits {
-            wait_clock_true!(sim, clock, x);
-            x.driver.cmd.next = if *bit {
-                I2CDriverCmd::SendTrue
-            } else {
-                I2CDriverCmd::SendFalse
-            };
-            x.driver.run.next = true;
-            wait_clock_cycle!(sim, clock, x);
-            x.driver.run.next = false;
-            x = sim.watch(|x| !x.driver.busy.val(), x)?;
-        }
-        x.driver.cmd.next = I2CDriverCmd::GetBit;
-        x.driver.run.next = true;
-        wait_clock_cycle!(sim, clock, x);
-        x.driver.run.next = false;
-        x = sim.watch(|x| !x.driver.busy.val(), x)?;
-        x.driver.cmd.next = I2CDriverCmd::SendStop;
-        x.driver.run.next = true;
-        wait_clock_cycle!(sim, clock, x);
-        x.driver.run.next = false;
-        x = sim.watch(|x| !x.driver.busy.val(), x)?;
-        sim.done(x)
-    });
-    sim.run_to_file(Box::new(uut), 1_000_000_000, "i2c_driver.vcd")
-        .unwrap()
-}
