@@ -2,14 +2,17 @@ pub mod accum;
 pub mod delay_line;
 pub mod dff;
 pub mod edge_detector;
+pub mod edge_ff;
 pub mod fifo;
 pub mod i2c;
 pub mod mac_fir;
 pub mod open_drain;
+pub mod png;
 pub mod prelude;
 pub mod pulser;
 pub mod pwm;
 pub mod ramrom;
+pub mod registered_edge_tristate;
 pub mod sdram;
 pub mod shot;
 pub mod spi;
